﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Threading.Tasks;

namespace PIbd_21_Potapov_N.S._Catamaran_Base
{
    class DrawCatamaran
    {
        public EntityCatamaran Catamaran { get; private set; }
        private int _StartPosX;
        private int _StartPosY;
        public int? _PictureWidth = null;   
        public int? _PictureHeight = null;
        private readonly int _CatamaranWidth = 80;
        private readonly int _CatamaranHeight = 50;

        public void Init(float w, Color c, Directions d, float v)
        {
            EntityCatamaran entityCatamaran = new EntityCatamaran();
            entityCatamaran.Init(w, c, d, v);
            Catamaran = entityCatamaran;
        }

        public void SetPosition(int x, int y, int? width, int height)
        {
            //todo проверки
            _StartPosX = x;
            _StartPosY = y;
            _PictureWidth = width;
            _PictureHeight = height;
        }

        public void MoveTransport(Directions direction)
        {
            if (!_PictureWidth.HasValue || !_PictureHeight.HasValue)
            {
                return;
            }

            switch (direction)
            {
                case Directions.Up:
                    if (_StartPosY - Catamaran.Step > 0)
                    {
                        _StartPosY -= (int)Catamaran.Step;
                    }
                    break;
                case Directions.Down:
                    if (_StartPosY + _CatamaranHeight + Catamaran.Step <= _PictureHeight)
                    {
                        _StartPosY += (int)Catamaran.Step;
                    }
                    break;
                case Directions.Left:
                    if (_StartPosX - Catamaran.Step > 0)
                    {
                        _StartPosX -= (int)Catamaran.Step;
                    }
                    break;
                case Directions.Right:
                    if (_StartPosX + _CatamaranWidth + Catamaran.Step < _PictureWidth)
                    {
                        _StartPosX += (int)Catamaran.Step;
                    }
                    break;
                default:
                    break;
            }
        }

        public void DrawTransport(Graphics g)
        {

            int nx = _StartPosX;
            int ny = _StartPosY;

            // Корпус катамарана
            g.DrawLine(Pens.Black, nx, ny, nx + _CatamaranWidth - 10, ny);
            g.DrawLine(Pens.Black, nx, ny + _CatamaranHeight, nx + _CatamaranWidth - 10, ny + _CatamaranHeight);

            g.DrawLine(Pens.Black, nx, ny, nx, ny + _CatamaranHeight);
            g.DrawLine(Pens.Black, nx + _CatamaranWidth, ny + 10, nx + _CatamaranWidth, ny + _CatamaranHeight - 10);

            g.DrawLine(Pens.Black, nx + _CatamaranWidth - 10, ny, nx + _CatamaranWidth, ny + 10);
            g.DrawLine(Pens.Black, nx + _CatamaranWidth - 10, ny + _CatamaranHeight, nx + _CatamaranWidth, ny + _CatamaranHeight - 10);
            //

            g.DrawEllipse(Pens.Black, nx + 10, ny + 10, _CatamaranWidth - 20, _CatamaranHeight - 20);

        }

        public void ChangeBorders(int nwidth, int nheight)
        {
            _PictureWidth = nwidth;
            _PictureHeight = nheight;
            if (_PictureWidth <= _CatamaranWidth || _PictureHeight <= _CatamaranHeight)
            {
                _PictureWidth = null;
                _PictureHeight = null;
                return;
            }
            if (_StartPosX + _CatamaranWidth > _PictureWidth)
            {
                _StartPosX = _PictureWidth.Value - _CatamaranWidth;
            }
            if (_StartPosY + _CatamaranHeight > _PictureHeight)
            {
                _StartPosY = _PictureHeight.Value - _CatamaranHeight;
            }
        }

        public string GetStatus()
        {
            string status = "";
            status += "Pos: " + _StartPosX + ", " + _StartPosY;
            return status;
        }
    }
}
